==> teamapps-application-server-0.9-sources.jar: org/teamapps/model/controlcenter/NewsBoardMessageImageQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface NewsBoardMessageImageQuery extends Query<NewsBoardMessageImage> {

    static NewsBoardMessageImageQuery create() {
        return new UdbNewsBoardMessageImageQuery();
    }

    NewsBoardMessageImageQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    NewsBoardMessageImageQuery parseFullTextFilter(String query, String... fieldNames);

	NewsBoardMessageImageQuery metaCreationDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaCreationDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaCreatedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaCreatedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaModificationDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaModificationDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaModifiedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaModifiedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaDeletionDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaDeletionDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaDeletedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaDeletedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaRestoreDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaRestoreDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaRestoredBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaRestoredBy(NumericFilter filter);

	NewsBoardMessageImageQuery file(FileFilter filter);

	NewsBoardMessageImageQuery orFile(FileFilter filter);

	NewsBoardMessageImageQuery thumbnail(FileFilter filter);

	NewsBoardMessageImageQuery orThumbnail(FileFilter filter);

	NewsBoardMessageImageQuery fileName(TextFilter filter);

	NewsBoardMessageImageQuery orFileName(TextFilter filter);

	NewsBoardMessageImageQuery embedded(BooleanFilter filter);

	NewsBoardMessageImageQuery orEmbedded(BooleanFilter filter);

	NewsBoardMessageImageQuery position(NumericFilter filter);

	NewsBoardMessageImageQuery orPosition(NumericFilter filter);


    NewsBoardMessageImageQuery andOr(NewsBoardMessageImageQuery... queries);

    NewsBoardMessageImageQuery customFilter(Function<NewsBoardMessageImage, Boolean> customFilter);

    List<NewsBoardMessageImage> execute();

    List<NewsBoardMessageImage> executeOnDeletedRecords();

    NewsBoardMessageImage executeExpectSingleton();

    BitSet executeToBitSet();

    List<NewsBoardMessageImage> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageImage> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}

==> teamapps-application-server-0.15-sources.jar: org/teamapps/model/controlcenter/NewsBoardMessageImageQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface NewsBoardMessageImageQuery extends Query<NewsBoardMessageImage> {

    static NewsBoardMessageImageQuery create() {
        return new UdbNewsBoardMessageImageQuery();
    }

    NewsBoardMessageImageQuery id(Integer... ids);

    NewsBoardMessageImageQuery id(BitSet ids);

    NewsBoardMessageImageQuery id(Collection<Integer> ids);

    NewsBoardMessageImageQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    NewsBoardMessageImageQuery parseFullTextFilter(String query, String... fieldNames);

	NewsBoardMessageImageQuery metaCreationDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaCreationDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaCreatedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaCreatedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaModificationDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaModificationDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaModifiedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaModifiedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaDeletionDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaDeletionDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaDeletedBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaDeletedBy(NumericFilter filter);

	NewsBoardMessageImageQuery metaRestoreDate(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaRestoreDate(NumericFilter filter);

	NewsBoardMessageImageQuery metaRestoredBy(NumericFilter filter);

	NewsBoardMessageImageQuery orMetaRestoredBy(NumericFilter filter);

	NewsBoardMessageImageQuery file(FileFilter filter);

	NewsBoardMessageImageQuery orFile(FileFilter filter);

	NewsBoardMessageImageQuery thumbnail(FileFilter filter);

	NewsBoardMessageImageQuery orThumbnail(FileFilter filter);

	NewsBoardMessageImageQuery fileName(TextFilter filter);

	NewsBoardMessageImageQuery orFileName(TextFilter filter);

	NewsBoardMessageImageQuery embedded(BooleanFilter filter);

	NewsBoardMessageImageQuery orEmbedded(BooleanFilter filter);

	NewsBoardMessageImageQuery position(NumericFilter filter);

	NewsBoardMessageImageQuery orPosition(NumericFilter filter);


    NewsBoardMessageImageQuery andOr(NewsBoardMessageImageQuery... queries);

    NewsBoardMessageImageQuery customFilter(Function<NewsBoardMessageImage, Boolean> customFilter);

    List<NewsBoardMessageImage> execute();

    List<NewsBoardMessageImage> executeOnDeletedRecords();

    NewsBoardMessageImage executeExpectSingleton();

    BitSet executeToBitSet();

    List<NewsBoardMessageImage> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageImage> execute(boolean deletedRecords, String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<NewsBoardMessageImage> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}
